---
title: 페이먼트월 해외결제 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: 페이먼트월 해외결제 서비스 이용안내
  description: >-
    해외 각국의 결제수단을 다양하게 제공하는 페이먼트월 서비스 안내드립니다. 가입방법, 입점기준, 결제 수수료, 결제 수단, 지원통화,
    정산, 문의처, 연동가이드, 결제 한도, 결제취소 금액, 정산환율, 취소 수수료까지 모두 확인해보세요.
  keywords:
    - 해외결제
tags:
  - 페이먼트월
  - 해외결제
pgCompanies:
  - 페이먼트월
searchTags:
  - 'RR '
  - PR
  - 페이먼트월 정기결제
  - 페이먼트월 일반결제
  - 페이먼트월
  - 해외결제
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="각국의 결제수단을 다양하게 제공하는 PG사인 '페이먼트월'의 서비스를 자세히 안내드립니다." />

### **페이먼트월 해외결제 서비스**



- 가입방법 : [포트원 관리자콘솔↗](https://admin.portone.io/auth/signin) 에서 '전자결제신청' 클릭하여 신청서 접수 \
  ('현지 결제수단' 이용시 체크 후 이용하실 국가명 선택 필수)
- 입점기준 : 최소 월 매출액 : $10,000 이상 입점 가능
  - 가입접수 > 매출 발생여부 확인 > 증빙(주문/결제내역) 제출
  - 국내 결제 $10,000 이상 발생시 심사 가능
- 이용료 : 월 관리비 적용 : 100USD / Monthly
  - 월 매출액 기준 없음(2023년 1월 1일 가입건 부터))
- 결제수수료 : [해외결제 수수료 표 보러가기↗](https://help.portone.io/category/pricing?location=oversea)
- 결제방식 : 페이먼트월 결제창을 통한 일반결제 방식
- 결제수단 : 글로벌 결제 , 해외 현지국가 결제
- 통화
  - 결제통화
    - 한국매입사 지원 통화(결제) : USD/JPY/KRW/EUR/RUB/HKD/AUD/GBP/CAD/THB
    - 현지 결제 : 현지 국가 별 현지통화만 지원
    - Alipay (CNY/USD 결제 가능)
  - 정산 통화 : USD / EUR
  - 정산방법 : 정산금액 지급은 월 1회에서 2회 자동으로 진행되며 매월 1일 혹은 15일에 약 1일에서 5일정도의 시간이 소요되어 진행됩니다.
    금액정산 및 지급은 고객사에서 선택하신 정산 방식에 따라 소요시간에 차이가 있으며 금액정산 예정일 및 정산률을 포함한 보고서 조회가 가능합니다
    - [페이먼트월 정산 QnA 보러가기↗](https://www.paymentwall.com/kr/faq/payouts/194)
  - 결제요청 한도기준 : 결제요청 가능한 최대 건별 한도 : USD 500 제공 , 한도 상향이 필요한 경우, 페이먼트월 요청하여 페이먼트월 내부 검토 후 상향 조정 안내.
  - 최소 결제 요청 가능한 금액 : 최소 결제금액 0.3 EUR (약 $0.5)  해외카드 단건/정기 모두 동일
  - 정산환율 :
    - 달러(USD) 정산 시에는 적용되는 환율은 없습니다. 다만, 결제 시 USD로 전환되는 환율은 있고 결제사별로 다르게 환율이 적용되므로, 페이먼트월 계약시 체크 필요합니다.
    - 일부 결제사는 결제 당일 실시간 고시환율로 USD 환전 정산 됩니다.
    - 일부 결제사는 일단 현지 통화로 결제 및 대금 수납 후 페이먼트월쪽에 정산하는 날짜의 환율로 USD 환전 적용 됩니다.
    - ‘대체결제 수단(현지결제/간편결제)’의 경우, 페이먼트월 결제 파트너사의 정산일의 환율 적용되며, ‘신용카드’ 같은 경우 매입사는 실시간 은행사 환율이 적용 됩니다.
    - ‘국내(발행)카드’는 결제는 KRW로 되지만 모든 정산은 USD로 처리되고 환율 기준은 결제사 별로 상이 합니다.
  - 참고사항 : 페이먼트월 정책상 결제를 시도하는 국가IP에 따라 결제수단이 노출됩니다. (국내에서 해외결제를 테스트하고자 하실 경우, 해당 국가의 vpn을 이용하여 IP변경 후 시도해주시면 됩니다)
  - 문의처 :  02-577-8474 / [seoul@paymentwall.com](mailto:seoul@payementwall.com) / paymentwall 홈페이지 내 질의가능
    - [페이먼트월 문의 페이지 보러가기↗](https://www.paymentwall.com/contacts)
  - 결제 취소(환불) 수수료 적용 기준 : 페이먼트월에서는 카드결제 취소 시 취소 수수료가 발생되지는 않습니다.
    - 매입 전(당일) 취소
      - 매입 전(당일) 취소 기준: 결제 당일 오후 11시 59분까지만 적용 가능.(국내 매입사 시스템 적용 기준 반영)
      - 매입 전(당일) 취소 시, 결제 수수료는 발생하지 않음. 이때 0.30USD도 발생하지 않음.
    - 매입 후 취소
      - 결제 당일 23시 59분 이후에는 환불로 프로세싱되며, 결제수수료 발생 및 환불에 시일 소요될 수 있습니다.
      - (매입 후 취소 시)결제 수수료 발생(반환 불가) 및 취소가 아닌 환불로 진행 필요하여 시간이 걸릴 수 있음.
      - X% + 0.30USD 반환 불가

### **페이먼트월 사이트 구현 기준**

<Callout title="페이먼트월 사이트 심사 가이드라인 보러가기↗" />

1. 웹사이트 내 모든 메뉴가 정상적으로 작동하여야 하며, 메뉴를 클릭했을 때 상품이나 콘텐츠가 확인되어야 합니다.
   리스트된 상품이 없는 메뉴 카테고리는 삭제를 권유 드립니다.
2. 테스트 결제 가능한 상품이 하나 이상 업로드되어 있어야 합니다.(테스트 상품 무방)
3. 웹사이트 하단에 법인 정보, 고객센터(CS)연락처, Terms of Services, Refund Policy, Privacy Policy, Shipping Policy가 모두 명시되어 있어야 합니다. (서비스 약관, 환불 정책, 개인 정보 보호 정책, 배송 정책)
4. 페이먼트월은 보증보험이 없으며, RR (Rolling Reserve) 으로 운영되고 있습니다.

<Callout content="**RR이란?**
해외PG는 한국 결제사처럼 보증보험 신청이나 선보증금을 받고 있지 않으나, 실결제 건 별 5%의 금액을 Rolling Reserve(RR)이라고 하여 리스크 대비 비용으로 약 6개월(차지백 소송 가능 기간) 동안 키핑해두었다가 돌려드리는 구조의 보증금 방식을 사용하고 있습니다." title="참고사항" icon="💡" />

<Callout title="페이먼트월 연동가이드 보러가기↗" />
